[Buildbot-commits] buildbot/buildbot/process base.py,1.45,1.46 interlock.py,1.5,1.6 builder.py,1.22,1.23

Brian Warner warner at users.sourceforge.net
Tue Apr 19 07:45:21 UTC 2005


Update of /cvsroot/buildbot/buildbot/buildbot/process
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv1721/buildbot/process

Modified Files:
	base.py interlock.py builder.py 
Log Message:
Revision: arch at buildbot.sf.net--2004/buildbot--dev--0--patch-47
Creator:  Brian Warner <warner at monolith.lothar.com>

merge doc updates [org.apestaart at thomas/buildbot--doc--0--patch-7]

more docs from Thomas, a few edits of my own.


Index: base.py
===================================================================
RCS file: /cvsroot/buildbot/buildbot/buildbot/process/base.py,v
retrieving revision 1.45
retrieving revision 1.46
diff -u -d -r1.45 -r1.46
--- base.py	18 Apr 2005 00:26:56 -0000	1.45
+++ base.py	19 Apr 2005 07:45:11 -0000	1.46
@@ -179,6 +179,9 @@
             self.timer = None
 
     def fireTimer(self):
+        """
+        Fire the build timer on the builder.
+        """
         self.timer = None
         self.nextBuildTime = None
         # tell the Builder to deal with us

Index: builder.py
===================================================================
RCS file: /cvsroot/buildbot/buildbot/buildbot/process/builder.py,v
retrieving revision 1.22
retrieving revision 1.23
diff -u -d -r1.22 -r1.23
--- builder.py	18 Apr 2005 00:26:56 -0000	1.22
+++ builder.py	19 Apr 2005 07:45:19 -0000	1.23
@@ -263,6 +263,13 @@
         # eventually, our buildTimerFired() method will be called
         
     def buildTimerFired(self, wb):
+        """
+        Called by the Build when the build timer fires.
+
+        @type  wb: L{buildbot.process.base.Build}
+        @param wb: the waiting build that fires the timer
+        """
+
         if not self.interlocks:
             # move from .waiting to .buildable
             if self.buildable:

Index: interlock.py
===================================================================
RCS file: /cvsroot/buildbot/buildbot/buildbot/process/interlock.py,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -d -r1.5 -r1.6
--- interlock.py	18 Apr 2005 00:26:56 -0000	1.5
+++ interlock.py	19 Apr 2005 07:45:19 -0000	1.6
@@ -13,13 +13,21 @@
     debug = 0
 
     def __init__(self, name, feeders, watchers):
+        """
+        @type  name: string
+        @param name: name of the interlock
+        @type  feeders: list of strings
+        @param feeders: names of the builders that feed this interlock
+        @type  watchers: list of strings
+        @param watchers: names of the builders that wait on this interlock
+        """
         self.name = name
         self.feederNames = feeders  # these feed me
         self.watcherNames = watchers  # these watch me
         self.feeders = {}
         for n in feeders:
             self.feeders[n] = (None, 0)
         # feeders.keys are .names of Build objects that we watch
         # feeders.values are Change numbers that have been successfully built
         self.watchers = {}
         # watchers.keys are Change numbers that a builder cares about
@@ -57,7 +65,25 @@
         for watcherName in self.watcherNames:
             builders[watcherName].stopWatchingInterlock(self)
 
+    # FIXME: maybe rename to changeProcessed instead ?
+    # that way it can be used for builders with unimportant changes
+    # to pass interlocks
     def buildFinished(self, feederName, changenum, successful):
+        """
+        Tell the interlock the build on the given builder with the given
+        changenum has finished.
+        In practice, this just informs the interlock that the given builder
+        has processed changes up to the given changenum, with the given
+        result.
+
+        @type  feederName: string
+        @param feederName: name of the builder that finished a build
+        @type  changenum:  int
+        @param changenum:  number of the L{buildbot.changes.changes.Change}
+                           that this builder finished a build for
+        @type  successful: bool
+        @param successful: whether the build succeeded
+        """
         # we assume that any given build will process Changes in strict order
         self.feeders[feederName] = (changenum, successful)
         if self.debug:
@@ -13,13 +13,21 @@
         for n in feeders:
             self.feeders[n] = (None, 0)
-        # feeders.keys are .names of Build objects that we watch
+        # feeders.keys are .names of Builder objects that we watch
         # feeders.values are Change numbers that have been successfully built
         self.watchers = {}





More information about the Commits mailing list